@@ -64,7 +64,10 @@ class MiddleStorm(object):
         except AttributeError:
             environ[self._key]  = \
                 self._local.__dict__.setdefault('store', Store(self._database))
-        return self._app(environ, start_response)
+        try:
+            return self._app(environ, start_response)
+        finally:
+            environ[self._key].rollback()    
 
 def decorator(database, key = 'storm.store'):
     """WSGI middleware decorator.
