@@ -3,6 +3,7 @@
 
 from storm.store import Store
 from storm.database import create_database
+from storm.properties import Int
 from unittest import TestCase
 from threading import Thread
 
@@ -88,3 +89,21 @@ class TestWsgi(TestCase):
         mt().join()
         
         self.assertNotEquals(stores[0], stores[1])
+
+	def test_clear_store(self):
+		class FakeTable(object):
+			__storm_table__ = 'fake_table'
+			id = Int(primary = True)
+		
+		ft = FakeTable()
+		
+		def fake_app(environ, start_response):
+			assert environ['storm.store'].of(ft) == None, 'not clean store after call app'
+			environ['storm.store'].add(ft)
+		
+		m = middlestorm.MiddleStorm(fake_app, fake_db)
+
+		e = {}
+		m(e, None)
+		e = {}
+		m(e, None)
